WOW: Weka Option Wizard

View source: R/wow.R

WOWR Documentation

Weka Option Wizard

Description

Give on-line information about available control options for Weka learners or filters and their R interfaces.

Usage

WOW(x)

Arguments

x

a character string giving either the fully qualified name of a Weka learner or filter class in JNI notation, or the name of an available R interface, or an object obtained from applying these interfaces to build an associator, classifier, clusterer, or filter.

Details

See list_Weka_interfaces for the available interface functions.

References

\bibshow

Hornik+Buchta+Zeileis:2008

Examples

## The name of an "existing" (registered) interface.
WOW("J48")
## The name of some Weka class (not necessarily in the interface
## registry):
WOW("weka/classifiers/bayes/NaiveBayes")

RWeka documentation built on July 27, 2026, 1:06 a.m.