| Weka_associators | R Documentation |
R interfaces to Weka association rule learning algorithms.
Apriori(x, control = NULL)
Tertius(x, control = NULL)
x |
an R object with the data to be associated. |
control |
an object of class |
Apriori implements an Apriori-type algorithm, which iteratively
reduces the minimum support until it finds the required number of
rules with the given minimum confidence.
Tertius implements a Tertius-type algorithm.
See the references for more information on these algorithms.
A list inheriting from class Weka_associators with components
including
associator |
a reference (of class
|
Tertius requires Weka package tertius to be installed.
Agrawal+Srikant:1994, Flach+Lachiche:2001, Witten+Frank:2005
x <- read.arff(system.file("arff", "contact-lenses.arff",
package = "RWeka"))
## Apriori with defaults.
Apriori(x)
## Some options: set required number of rules to 20.
Apriori(x, Weka_control(N = 20))
## Not run:
## Requires Weka package 'tertius' to be installed.
## Tertius with defaults.
Tertius(x)
## Some options: only classification rules (single item in the RHS).
Tertius(x, Weka_control(S = TRUE))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.