| Weka_filters | R Documentation |
R interfaces to Weka filters.
Normalize(formula, data, subset, na.action, control = NULL)
Discretize(formula, data, subset, na.action, control = NULL)
formula |
a symbolic description of a model. Note that for unsupervised filters the response can be omitted. |
data |
an optional data frame containing the variables in the model. |
subset |
an optional vector specifying a subset of observations to be used in the fitting process. |
na.action |
a function which indicates what should happen when
the data contain |
control |
an object of class |
Normalize implements an unsupervised filter that normalizes all
instances of a dataset to have a given norm. Only numeric values are
considered, and the class attribute is ignored.
Discretize implements a supervised instance filter that
discretizes a range of numeric attributes in the dataset into nominal
attributes. Discretization is by the MDL method of
\bibcitetFayyad+Irani:1993.
Note that these methods ignore nominal attributes, i.e., variables of
class factor.
A data frame.
Fayyad+Irani:1993, Witten+Frank:2005
## Using a Weka data set ...
w <- read.arff(system.file("arff","weather.arff",
package = "RWeka"))
## Normalize (response irrelevant)
m1 <- Normalize(~., data = w)
m1
## Discretize
m2 <- Discretize(play ~., data = w)
m2
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.